@@ -281,10 +281,9 @@ raptor_turtle_emit_blank(raptor_serializer *serializer,
           
   } else {
     /* Blank node that needs an explicit name */
-    const unsigned char *node_id = node->term->value.blank.string;
-
-    raptor_turtle_writer_raw(context->turtle_writer, (const unsigned char*)"_:");
-    raptor_turtle_writer_raw(context->turtle_writer, node_id);
+    raptor_turtle_writer_bnodeid(context->turtle_writer,
+                                 node->term->value.blank.string,
+                                 node->term->value.blank.string_len);
   }
 
   RAPTOR_DEBUG2("Emitted %p\n", node);
@@ -678,7 +677,7 @@ raptor_turtle_emit_subject(raptor_serializer *serializer,
       const unsigned char* genid = subject->node->term->value.blank.string;
       size_t len = strlen((const char*)genid);
       unsigned char* subject_str;
-      subject_str= (unsigned char *)RAPTOR_MALLOC(cstring, len+3);
+      subject_str= RAPTOR_MALLOC(unsigned char*, len + 3);
       if(!subject_str)
         return 1;
 
@@ -686,7 +685,7 @@ raptor_turtle_emit_subject(raptor_serializer *serializer,
       subject_str[1]=':';
       memcpy(&subject_str[2], genid, len + 1);
       raptor_turtle_writer_raw(turtle_writer, subject_str);
-      RAPTOR_FREE(cstring, subject_str);
+      RAPTOR_FREE(char*, subject_str);
     }
   } 
 
@@ -1144,13 +1143,15 @@ raptor_turtle_serialize_finish_factory(raptor_serializer_factory* factory)
 
 static const char* const turtle_names[2] = { "turtle", NULL};
 
-static const char* const turtle_uri_strings[2] = {
+static const char* const turtle_uri_strings[3] = {
+  "http://www.w3.org/ns/formats/Turtle",
   "http://www.dajobe.org/2004/01/turtle/",
   NULL
 };
   
-#define TURTLE_TYPES_COUNT 5
+#define TURTLE_TYPES_COUNT 6
 static const raptor_type_q turtle_types[TURTLE_TYPES_COUNT + 1] = {
+  { "text/turtle", 11, 10},
   { "application/turtle", 18, 10},
   { "application/x-turtle", 20, 8},
   { "text/n3", 7, 3},
